#
# Conditional build:
%bcond_without	doc	# don't build doc
%bcond_with	tests	# run tests
%bcond_without	python2 # CPython 2.x module
%bcond_without	python3 # CPython 3.x module

%define 	module		rtmidi
%define		pypi_name	python-rtmidi
Summary:	A Python wrapper for the RtMidi C++ library
Name:		python-%{module}
Version:	1.1.0
Release:	5
License:	MIT
Group:		Libraries/Python
Source0:	https://files.pythonhosted.org/packages/source/p/%{pypi_name}/%{pypi_name}-%{version}.zip
# Source0-md5:	dac7edb268a8dcd454fbeeb19ac6fb07
URL:		http://trac.chrisarndt.de/code/wiki/python-rtmidi
BuildRequires:	rpm-pythonprov
BuildRequires:	rpmbuild(macros) >= 1.714
%if %{with python2}
BuildRequires:	python-devel
BuildRequires:	python-setuptools
%endif
%if %{with python3}
BuildRequires:	python3-devel
BuildRequires:	python3-setuptools
%endif
%if %{with doc}
BuildRequires:	sphinx-pdg
%endif
BuildRequires:	rtmidi-devel
Requires:	python-modules
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
python-rtmidi is a Python binding for RtMidi implemented with ​Cython
and provides a thin wrapper around the RtMidi C++ interface. The API
is basically the same as the C++ one but with the naming scheme of
classes, methods and parameters adapted to the Python PEP-8
conventions and requirements of the Python package naming structure.

%package -n python3-%{module}
Summary:	A Python wrapper for the RtMidi C++ library
Group:		Libraries/Python
Requires:	python3-modules

%description -n python3-%{module}
python-rtmidi is a Python binding for RtMidi implemented with ​Cython
and provides a thin wrapper around the RtMidi C++ interface. The API
is basically the same as the C++ one but with the naming scheme of
classes, methods and parameters adapted to the Python PEP-8
conventions and requirements of the Python package naming structure.

%package apidocs
Summary:	%{module} API documentation
Summary(pl.UTF-8):	Dokumentacja API %{module}
Group:		Documentation

%description apidocs
API documentation for %{module}.

%description apidocs -l pl.UTF-8
Dokumentacja API %{module}.

%prep
%setup -q

%build
%if %{with python2}
%py_build %{?with_tests:test}
%endif

%if %{with python3}
%py3_build %{?with_tests:test}
%endif

%if %{with doc}
cd docs
%{__make} -j1 html
rm -rf _build/html/_sources
%endif

%install
rm -rf $RPM_BUILD_ROOT
%if %{with python2}
%py_install
%py_postclean
%endif

%if %{with python3}
%py3_install
%endif

%if %{with python2}
install -d $RPM_BUILD_ROOT%{_examplesdir}/python-%{module}-%{version}
cp -a examples/* $RPM_BUILD_ROOT%{_examplesdir}/python-%{module}-%{version}
find $RPM_BUILD_ROOT%{_examplesdir}/python-%{module}-%{version} -name '*.py' \
	| xargs sed -i '1s|^#!.*python\b|#!%{__python}|'
%endif
%if %{with python3}
install -d $RPM_BUILD_ROOT%{_examplesdir}/python3-%{module}-%{version}
cp -a examples/* $RPM_BUILD_ROOT%{_examplesdir}/python3-%{module}-%{version}
find $RPM_BUILD_ROOT%{_examplesdir}/python3-%{module}-%{version} -name '*.py' \
	| xargs sed -i '1s|^#!.*python\b|#!%{__python3}|'
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%if %{with python2}
%files
%defattr(644,root,root,755)
%doc AUTHORS.rst CHANGELOG.rst README.rst
%dir %{py_sitedir}/%{module}
%{py_sitedir}/%{module}/*.py[co]
%attr(755,root,root) %{py_sitedir}/%{module}/*.so
%{py_sitedir}/python_rtmidi-%{version}-py*.egg-info
%{_examplesdir}/%{name}-%{version}
%endif

%if %{with python3}
%files -n python3-%{module}
%defattr(644,root,root,755)
%doc AUTHORS.rst CHANGELOG.rst README.rst
%dir %{py3_sitedir}/%{module}
%{py3_sitedir}/%{module}/*.py
%attr(755,root,root) %{py3_sitedir}/%{module}/*.so
%{py3_sitedir}/%{module}/__pycache__
%{py3_sitedir}/python_rtmidi-%{version}-py*.egg-info
%{_examplesdir}/python3-%{module}-%{version}
%endif

%if %{with doc}
%files apidocs
%defattr(644,root,root,755)
%doc docs/_build/html/*
%endif
%changelog
* Sat Nov 20 2021 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/python-rtmidi.git;a=log;h=master

* Sat Nov 20 2021 Jan Rękorajski <baggins@pld-linux.org> 00788fe
- rebuild with separate debuginfo build-ids

* Sat Feb 27 2021 Jan Rękorajski <baggins@pld-linux.org> 5421c42
- release 4 (by relup.sh)

* Mon Oct 28 2019 Jan Rękorajski <baggins@pld-linux.org> 802217b
- rebuild with python 3.8
- release 3 (by relup.sh)

* Tue Jul 03 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> 64b9600
- release 2 (by relup.sh)

* Wed Nov 22 2017 Jacek Konieczny <j.konieczny@eggsoft.pl> 86269b3
- disable tests

* Wed Nov 22 2017 Jacek Konieczny <j.konieczny@eggsoft.pl> 4d10270
- new package

